@@ -1,8 +1,5 @@
 """Docker container management for Otter Grade"""
-
-import docker
 import glob
-import itertools
 import os
 import pandas as pd
 import pickle
@@ -11,8 +8,8 @@ import shutil
 import tempfile
 
 from concurrent.futures import ThreadPoolExecutor, wait
-from docker.errors import BuildError, ImageNotFound
-from docker.utils.json_stream import json_stream
+from python_on_whales import docker
+from typing import Optional
 
 from .utils import generate_hash, OTTER_DOCKER_IMAGE_TAG
 
@@ -31,36 +28,21 @@ def build_image(zip_path, base_image, tag):
     """
     image = OTTER_DOCKER_IMAGE_TAG + ":" + tag
     dockerfile = pkg_resources.resource_filename(__name__, "Dockerfile")
-    docker_version = os.environ.get("OTTER_DOCKER_CLIENT_VERSION", "auto")
-    client = docker.from_env(version=docker_version)
 
-    try:
-        client.images.get(image)
-
-    except ImageNotFound:
+    if not docker.image.exists(image):
         print(f"Building new image using {base_image} as base image")
-        generator = client.api.build(buildargs={
+        docker.build(".", build_args={
             "ZIPPATH": zip_path,
             "BASE_IMAGE": base_image
-        }, tag=image, dockerfile=dockerfile, path=".")
-        
-        result_stream, internal_stream = itertools.tee(json_stream(generator))
-        for chunk in internal_stream:
-            if 'error' in chunk:
-                raise BuildError(chunk['error'], result_stream)
-            if 'stream' in chunk:
-                line = chunk['stream'].strip("\r\n")
-                if len(line) != 0:
-                    print(line)
+        }, tags=[image], file=dockerfile)
 
-    client.close()
     return image
 
 
 def launch_grade(zip_path, notebooks_dir, verbose=False, num_containers=None,
                  scripts=False, no_kill=False, output_path="./", debug=False, zips=False,
                  image="ucbdsinfra/otter-grader",
-                 pdfs=False):
+                 pdfs=False, timeout=None, network=True):
     """
     Grades notebooks in parallel Docker containers
 
@@ -83,6 +65,8 @@ def launch_grade(zip_path, notebooks_dir, verbose=False, num_containers=None,
         zips (``bool``, optional): whether the submissions are zip files formatted from ``Notebook.export``
         image (``str``, optional): a base image to use for building Docker images
         pdfs (``bool``, optional): whether to copy PDFs out of the containers
+        timeout (``int``): timeout in seconds for each container
+        network (``bool``): whether to enable networking in the containers
 
     Returns:
         ``list`` of ``pandas.core.frame.DataFrame``: the grades returned by each container spawned during
@@ -114,6 +98,8 @@ def launch_grade(zip_path, notebooks_dir, verbose=False, num_containers=None,
                 output_path=output_path,
                 debug=debug,
                 pdfs=pdfs,
+                timeout=timeout,
+                network=network,
             )
         ]
 
@@ -127,7 +113,8 @@ def launch_grade(zip_path, notebooks_dir, verbose=False, num_containers=None,
 # TODO: these arguments need to be updated. replace notebooks_dir with the path to the notebook that
 # this container will be grading
 def grade_assignments(submission_path, image="ucbdsinfra/otter-grader", verbose=False,
-                      scripts=False, no_kill=False, output_path="./", debug=False, pdfs=False):
+                      scripts=False, no_kill=False, output_path="./", debug=False, pdfs=False,
+                      timeout: Optional[int] = None, network=True):
     """
     Grades multiple submissions in a directory using a single docker container. If no PDF assignment is
     wanted, set all three PDF params (``unfiltered_pdfs``, ``tag_filter``, and ``html_filter``) to ``False``.
@@ -144,13 +131,12 @@ def grade_assignments(submission_path, image="ucbdsinfra/otter-grader", verbose=
         debug (``bool``, False): whether to run grading in debug mode (prints grading STDOUT and STDERR
             from each container to the command line)
         pdfs (``bool``, optional): whether to copy PDFs out of the containers
+        timeout (``int``): timeout in seconds for each container
+        network (``bool``): whether to enable networking in the containers
 
     Returns:
         ``pandas.core.frame.DataFrame``: A dataframe of file to grades information
     """
-    # this is a fix for travis -- allows overriding docker client version
-    docker_version = os.environ.get("OTTER_DOCKER_CLIENT_VERSION", "auto")
-    client = docker.from_env(version=docker_version)
 
     _, temp_subm_path = tempfile.mkstemp()
     shutil.copyfile(submission_path, temp_subm_path)
@@ -164,26 +150,46 @@ def grade_assignments(submission_path, image="ucbdsinfra/otter-grader", verbose=
         nb_basename = os.path.basename(submission_path)
         nb_name = os.path.splitext(nb_basename)[0]
 
-        volumes = {
-            f"{temp_subm_path}": {'bind': f"/autograder/submission/{nb_basename}"},
-            f"{results_path}": {'bind': "/autograder/results/results.pkl"}
-        }
+        volumes = [
+            (temp_subm_path, f"/autograder/submission/{nb_basename}"),
+            (results_path, "/autograder/results/results.pkl")
+        ]
         if pdfs:
-            volumes.update({f"{pdf_path}": {"bind": f"/autograder/submission/{nb_name}.pdf"}})
-        container = client.containers.run(image, "/autograder/run_autograder", volumes=volumes,
-                                          detach=True, tty=False)
+            volumes.append((pdf_path, f"/autograder/submission/{nb_name}.pdf"))
+
+        args = {}
+
+        if network is not None and not network:
+            args['networks'] = 'none'
+
+        container = docker.container.run(image, command=["/autograder/run_autograder"], volumes=volumes, detach=True, **args)
+
+        if timeout:
+            import threading
+
+            def kill_container():
+                docker.container.kill(container)
+
+            timer = threading.Timer(timeout, kill_container)
+            timer.start()
 
         if verbose:
             print(f"Grading {submission_path} in container {container.id}...")
 
-        container.wait()
+        exit = docker.container.wait(container)
+
+        if timeout:
+            timer.cancel()
 
         if debug:
-            print(container.logs(stderr=True, stdout=True).decode("utf-8"))
+            print(docker.container.logs(container))
 
         if not no_kill:
             container.remove()
 
+        if exit != 0:
+            raise Exception(f"Executing '{submission_path}' in docker container failed! Exit code: {exit}")
+
         with open(results_file, "rb") as f:
             scores = pickle.load(f)
 
@@ -200,7 +206,6 @@ def grade_assignments(submission_path, image="ucbdsinfra/otter-grader", verbose=
             shutil.copy(pdf_path, local_pdf_path)
 
     finally:
-        client.close()
         os.remove(results_path)
         os.remove(temp_subm_path)
         if pdfs:
