@@ -12,15 +12,15 @@ from subprocess import PIPE
 from glob import glob
 from unittest.mock import patch
 
-# from otter.argparser import get_parser
 from otter.assign import main as assign
 from otter.generate.token import APIClient
-from otter.runner import run_otter
 
 from . import TestCase
 
+
 TEST_FILES_PATH = "test/test-assign/"
 
+
 class TestAssign(TestCase):
 
     def check_gradescope_zipfile(self, path, correct_dir_path):
@@ -40,13 +40,7 @@ class TestAssign(TestCase):
         Checks that otter assign filters and outputs correctly
         """
         # run otter assign
-        run_assign_args = [
-            "assign", "--no-run-tests", TEST_FILES_PATH + "example.ipynb", TEST_FILES_PATH + "output",
-        ]
-        # args = parser.parse_args(run_assign_args)
-        # args.func = assign
-        # args.func(args)
-        run_otter(run_assign_args)
+        assign(TEST_FILES_PATH + "example.ipynb", TEST_FILES_PATH + "output", no_run_tests=True, v1=True)
        
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "example-correct")
         
@@ -54,14 +48,7 @@ class TestAssign(TestCase):
         """
         Checks that otter assign filters and outputs correctly, as well as creates a correct .otter file
         """
-        run_assign_args = [
-            "assign",  TEST_FILES_PATH + "generate-otter.ipynb", 
-            TEST_FILES_PATH + "output",
-        ]
-        # args = parser.parse_args(run_assign_args)
-        # args.func = assign
-        # args.func(args)
-        run_otter(run_assign_args)
+        assign(TEST_FILES_PATH + "generate-otter.ipynb", TEST_FILES_PATH + "output")
         
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "otter-correct")     
 
@@ -69,39 +56,21 @@ class TestAssign(TestCase):
         """
         Checks that otter assign filters and outputs correctly, as well as creates a correct .zip file along with PDFs
         """
-        run_assign_args = [
-            "assign", "--no-run-tests", TEST_FILES_PATH + "generate-pdf.ipynb", TEST_FILES_PATH + "output",
-        ]
-        # args = parser.parse_args(run_assign_args)
-        # args.func = assign
-        # args.func(args)
-        run_otter(run_assign_args)
+        assign(TEST_FILES_PATH + "generate-pdf.ipynb", TEST_FILES_PATH + "output", no_run_tests=True)
       
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "pdf-correct", ignore_ext=[".pdf",".zip"])
-        
-        # # check gradescope zip file
-        # self.check_gradescope_zipfile(
-        #     TEST_FILES_PATH + "output/autograder/autograder.zip", TEST_FILES_PATH + "pdf-autograder-correct",
-        # )
     
-    @patch.object(APIClient,"get_token")
+    @patch.object(APIClient, "get_token")
     def test_gradescope_example(self, mocked_client):
-
         """
         Checks that otter assign filters and outputs correctly, as well as creates a correct .zip file along with PDFs.
         Additionally, includes testing Gradescope integration.
         """
+        # set a return value that does not match the token in the notebook, so we'll know if APIClient
+        # is called
+        mocked_client.return_value = 'token'  
 
-        mocked_client.return_value = 'token'
-        
-        run_gradescope_args = [
-            "assign", "--no-run-tests", TEST_FILES_PATH + "generate-gradescope.ipynb", 
-            TEST_FILES_PATH + "output",
-        ]
-        # args = parser.parse_args(run_gradescope_args)
-        # args.func = assign
-        # args.func(args)
-        run_otter(run_gradescope_args)
+        assign(TEST_FILES_PATH + "generate-gradescope.ipynb", TEST_FILES_PATH + "output", no_run_tests=True)
       
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "gs-correct", ignore_ext=[".pdf",".zip"])
 
@@ -114,36 +83,18 @@ class TestAssign(TestCase):
         """
         Checks that otter assign works for R notebooks correctly
         """
-        run_assign_args = [
-            "assign", TEST_FILES_PATH + "r-example.ipynb", 
-            TEST_FILES_PATH + "output",
-        ]
-        # args = parser.parse_args(run_assign_args)
-        # args.func = assign
-        # args.func(args)
-        run_otter(run_assign_args)
+        assign(TEST_FILES_PATH + "r-example.ipynb", TEST_FILES_PATH + "output", v1=True)
 
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "r-correct", ignore_ext=[".pdf",".zip"])
-        
-        # # check gradescope zip file
-        # self.check_gradescope_zipfile(
-        #     TEST_FILES_PATH + "output/autograder/autograder.zip", TEST_FILES_PATH + "r-autograder-correct",
-        # )
 
     def test_rmd_example(self):
         """
         Checks that otter assign works for Rmd files
         """
-        run_assign_args = [
-            "assign", TEST_FILES_PATH + "rmd-example.Rmd", 
-            TEST_FILES_PATH + "output",
-        ]
-        # args = parser.parse_args(run_assign_args)
-        # args.func = assign
-        # args.func(args)
-        run_otter(run_assign_args)
+        assign(TEST_FILES_PATH + "rmd-example.Rmd", TEST_FILES_PATH + "output", v1=True)
 
-        self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "rmd-correct", ignore_ext=[".zip"])
+        self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "rmd-correct", 
+            ignore_ext=[".zip", ".pdf"], ignore_dirs=["rmd-example-sol_files"])
         
         # check gradescope zip file
         self.check_gradescope_zipfile(
